# audio-dataset-converter-visualization
Adds support for visualizing audio data.

## Installation

```bash
pip install git+https://github.com/waikato-llm/audio-dataset-converter.git
pip install git+https://github.com/waikato-llm/audio-dataset-converter-visualization.git
```

## Plugins

See [here](plugins/README.md) for an overview of all plugins.
